@@ -1,4 +1,4 @@
-/* 06may11abu
+/* 29oct11abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -257,10 +257,14 @@ function post(form, file) {
       if (!file)
          FormReq.send(data);
       else {
-         FormReq.setRequestHeader("X-Pil", "*ContLen=");
-         FormReq.sendAsBinary(data + "&*Drop=" +
-            encodeURIComponent(file.name) + "=" +
-            file.size + "\n" + file.getAsBinary() );
+         var rd = new FileReader();
+         rd.readAsBinaryString(file);
+         rd.onload = function() {
+            FormReq.setRequestHeader("X-Pil", "*ContLen=");
+            FormReq.sendAsBinary(data + "&*Drop=" +
+               encodeURIComponent(file.name) + "=" +
+               file.size + "\n" + rd.result );
+         }
       }
    }
    catch (e) {
